import globals from 'globals';
import js from '@eslint/js';
import stylisticJs from '@stylistic/eslint-plugin-js';

export default [
    js.configs.recommended,
    {
        languageOptions: {
            globals: {
                ...globals.browser,
                ...globals.node,
            },
            ecmaVersion: 2020,
            sourceType: 'module',
        },
        plugins: {
            '@stylistic/js': stylisticJs
        },
        rules: {
            // possible problems
            'array-callback-return': 2,
            'no-await-in-loop': 2,
            'no-constructor-return': 2,
            'no-duplicate-imports': 2,
            'no-promise-executor-return': 2,
            'no-self-compare': 2,
            'no-template-curly-in-string': 2,
            'no-unmodified-loop-condition': 2,
            'no-unreachable-loop': 2,
            'no-use-before-define': [2, 'nofunc'],
            'no-useless-assignment': 2,
            'require-atomic-updates': 2,

            // suggestions
            'accessor-pairs': 2,
            'arrow-body-style': 2,
            'camelcase': 2,
            'class-methods-use-this': 2,
            'consistent-return': 2,
            'dot-notation': 2,
            'eqeqeq': [2, 'smart'],
            'func-name-matching': 2,
            'grouped-accessor-pairs': 2,
            'new-cap': 2,
            'no-array-constructor': 2,
            'no-caller': 2,
            'no-else-return': 2,
            'no-extend-native': 2,
            'no-extra-bind': 2,
            'no-extra-label': 2,
            'no-invalid-this': 2,
            'no-iterator': 2,
            'no-labels': 2,
            'no-lone-blocks': 2,
            'no-lonely-if': 2,
            'no-loop-func': 2,
            'no-new': 2,
            'no-new-wrappers': 2,
            'no-object-constructor': 2,
            'no-proto': 2,
            'no-return-assign': 2,
            'no-sequences': 2,
            'no-throw-literal': 2,
            'no-undef-init': 2,
            'no-unneeded-ternary': 2,
            'no-unused-expressions': 2,
            'no-useless-call': 2,
            'no-useless-computed-key': 2,
            'no-useless-concat': 2,
            'no-useless-constructor': 2,
            'no-useless-escape': 2,
            'no-useless-rename': 2,
            'no-useless-return': 2,
            'no-var': 2,
            'no-void': 2,
            'no-with': 2,
            'object-shorthand': 2,
            'prefer-arrow-callback': 2,
            'prefer-const': 2,
            'prefer-promise-reject-errors': 2,
            'prefer-rest-params': 2,
            'prefer-spread': 2,
            'prefer-numeric-literals': 2,
            'prefer-template': 2,
            'prefer-regex-literals': 2,
            'require-await': 2,
            'strict': 2,
            'yoda': 2,

            // stylistic
            '@stylistic/js/indent': [2, 4, {flatTernaryExpressions: true}],
            '@stylistic/js/array-bracket-spacing': 2,
            '@stylistic/js/arrow-parens': [2, 'as-needed', {requireForBlockBody: true}],
            '@stylistic/js/arrow-spacing': 2,
            '@stylistic/js/block-spacing': 2,
            '@stylistic/js/brace-style': [2, '1tbs', {allowSingleLine: true}],
            '@stylistic/js/comma-spacing': 2,
            '@stylistic/js/comma-style': 2,
            '@stylistic/js/computed-property-spacing': 2,
            '@stylistic/js/dot-location': [2, 'property'],
            '@stylistic/js/eol-last': 2,
            '@stylistic/js/function-call-spacing': 2,
            '@stylistic/js/key-spacing': 2,
            '@stylistic/js/keyword-spacing': 2,
            '@stylistic/js/new-parens': 2,
            '@stylistic/js/no-mixed-spaces-and-tabs': 2,
            '@stylistic/js/no-trailing-spaces': 2,
            '@stylistic/js/no-whitespace-before-property': 2,
            '@stylistic/js/object-curly-spacing': 2,
            '@stylistic/js/operator-linebreak': [2, 'after'],
            '@stylistic/js/quotes': [2, 'single'],
            '@stylistic/js/linebreak-style': [2, 'unix'],
            '@stylistic/js/semi': [2, 'always'],
            '@stylistic/js/semi-spacing': 2,
            '@stylistic/js/generator-star-spacing': 2,
            '@stylistic/js/rest-spread-spacing': 2,
            '@stylistic/js/yield-star-spacing': 2,
            '@stylistic/js/template-tag-spacing': 2,
            '@stylistic/js/no-confusing-arrow': 2,
            '@stylistic/js/implicit-arrow-linebreak': 2,
            '@stylistic/js/space-before-blocks': 2,
            '@stylistic/js/space-before-function-paren': [2, {anonymous: 'always', named: 'never'}],
            '@stylistic/js/space-in-parens': 2,
            '@stylistic/js/space-infix-ops': 2,
            '@stylistic/js/space-unary-ops': 2,
            '@stylistic/js/switch-colon-spacing': 2
        }
    }
];
